@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 1998 - 2018
+  Copyright (c) 1998 - 2020
   CLST  - Radboud University
   ILK   - Tilburg University
   CLiPS - University of Antwerp
@@ -79,15 +79,15 @@ namespace Tagger {
     return false;
   }
 
-template <typename T1, typename T2>
-struct more_second {
+  template <typename T1, typename T2>
+  struct more_second {
     typedef pair<T1, T2> type;
     bool operator ()(type const& a, type const& b) const {
-        return a.second > b.second;
+      return a.second > b.second;
     }
-};
+  };
 
-  void TaggerClass::create_lexicons(){
+  bool TaggerClass::create_lexicons(){
     TagLex TaggedLexicon;
     ifstream lex_file;
     ofstream out_file;
@@ -98,13 +98,13 @@ struct more_second {
 	     !lex_file.good() ) ){
 	cerr << "couldn't open tagged lexicon file `"
 	     << filename << "'" << endl;
-	exit(EXIT_FAILURE);
+	return false;
       }
       COUT << "Constructing a tagger from: " << filename << endl;
     }
     else {
       cerr << "couldn't open inputfile " << filename << endl;
-      exit(EXIT_FAILURE);
+      return false;
     }
 
     map<string,unsigned int> TagList;
@@ -128,7 +128,7 @@ struct more_second {
     }
     else {
       cerr << "couldn't create lexiconfile " << LexFileName << endl;
-      exit(EXIT_FAILURE);
+      return false;
     }
     for ( auto const& tv : TagVect ){
       ProcessTags( tv );
@@ -138,21 +138,22 @@ struct more_second {
       COUT << "  Creating ambitag lexicon: "  << MTLexFileName << endl;
       for ( const auto& tv : TagVect ){
 	out_file << tv->Word << " " << tv->stringRep() << endl;
-	MT_lexicon->Store( tv->Word, tv->stringRep() );
+	MT_lexicon->insert( make_pair(tv->Word, tv->stringRep() ) );
       }
       out_file.close();
     }
     else {
       cerr << "couldn't create file: " << MTLexFileName << endl;
-      exit(EXIT_FAILURE);
+      return false;
     }
     if ( (out_file.open( TopNFileName, ios::out ),
 	  out_file.good() ) ){
       COUT << "  Creating list of most frequent words: "  << TopNFileName << endl;
       int k = 0;
       for ( auto const& tv : TagVect ){
-	if ( ++k > TopNumber )
+	if ( ++k > TopNumber ){
 	  break;
+	}
 	out_file << tv->Word << endl;
 	kwordlist->Hash( tv->Word );
       }
@@ -160,26 +161,23 @@ struct more_second {
     }
     else {
       cerr << "couldn't open file: " << TopNFileName << endl;
-      exit(EXIT_FAILURE);
+      return false;
     }
     if ( DoNpax ){
       if ( (out_file.open( NpaxFileName, ios::out ),
 	    out_file.good() ) ){
-	int np_cnt = 0;
-	//	COUT << "  Creating Npax file: "  << NpaxFileName;
 	for ( const auto& tv : TagVect ){
-	  if ( tv->Freq() > Npax )
+	  if ( tv->Freq() > Npax ){
 	    continue;
+	  }
 	  out_file << tv->Word << endl;
 	  uwordlist->Hash( tv->Word );
-	  np_cnt++;
 	}
 	out_file.close();
-	//	COUT << "( " << np_cnt << " entries)" << endl;
       }
       else {
 	cerr << "couldn't open file: " << NpaxFileName << endl;
-	exit(EXIT_FAILURE);
+	return false;
       }
     }
     if ( DoTagList ){
@@ -193,8 +191,10 @@ struct more_second {
       }
       else {
 	cerr << "couldn't open outputfile: " << TagListName << endl;
+	return false;
       }
     }
+    return true;
   }
 
   bool TaggerClass::InitLearning( ){
@@ -202,11 +202,15 @@ struct more_second {
     // name for both output files (concatenation of datafile
     // and pattern string)
     //
-    create_lexicons();
-    if ( TimblOptStr.empty() )
+    if ( !create_lexicons() ){
+      return false;
+    }
+    if ( TimblOptStr.empty() ){
       Timbl_Options = "-a IB1 -G0";
-    else
+    }
+    else {
       Timbl_Options = TimblOptStr;
+    }
     splits( Timbl_Options, commonstr, knownstr, unknownstr );
     get_weightsfile_name( knownstr, kwf );
     get_weightsfile_name( unknownstr, uwf );
@@ -215,12 +219,11 @@ struct more_second {
 
   int TaggerClass::makedataset( istream& infile, bool do_known ){
     int no_words=0;
-    int no_sentences=0;
     int nslots=0;
     ofstream outfile;
     MatchAction Action;
     vector<int> TestPat;
-    if( do_known ){
+    if ( do_known ){
       nslots = Ktemplate.totalslots() - Ktemplate.skipfocus;
       outfile.open( K_option_name, ios::trunc | ios::out );
       Action = MakeKnown;
@@ -238,8 +241,9 @@ struct more_second {
     size_t line_cnt = 0;
     sentence mySentence( Ktemplate, Utemplate );
     while ( mySentence.read( infile, input_kind, EosMark, Separators, line_cnt ) ){
-      if ( mySentence.size() == 0 )
+      if ( mySentence.size() == 0 ){
 	continue;
+      }
       // cerr << mySentence << endl;
       if ( mySentence.getword(0) == EosMark ){
 	// only possible for ENRICHED!
@@ -265,14 +269,15 @@ struct more_second {
 				   swcn ) ){
 	  bool skip = false;
 	  if ( DoNpax && !do_known ){
-	    if((uwordlist->Lookup(mySentence.getword(swcn)))==0){
+	    if ( (uwordlist->Lookup(mySentence.getword(swcn))) == 0 ){
 	      skip = true;
 	    }
 	  }
-	  if ( !skip )
-	    for( int f=0; f < nslots; ++f ){
+	  if ( !skip ){
+	    for ( int f=0; f < nslots; ++f ){
 	      outfile << indexlex( TestPat[f], TheLex ) << " ";
 	    }
+	  }
 	  int thisTagCode = -1;
 #pragma omp critical (hasher)
 	  {
@@ -288,7 +293,6 @@ struct more_second {
 	  ++swcn;
 	  ++no_words;
 	}
-	no_sentences++;
       }
     }
 //      default_cout << "Output written to ";
@@ -305,13 +309,16 @@ struct more_second {
       COUT << "  Create known words case base,"
 	   << "   Timbl options: '" << knownstr + commonstr << "'" << endl;
       TimblAPI *Ktree = new TimblAPI( knownstr + commonstr );
-      if ( !Ktree->Valid() )
-	exit(EXIT_FAILURE);
+      if ( !Ktree->Valid() ){
+	cerr << "unable to create Timbl(" << knownstr + commonstr
+	     << ") for Known words." << endl;
+	return -1; // signal a failure
+      }
       COUT << "    Algorithm = " << to_string(Ktree->Algo()) << endl;
       if ( !piped_input ){
 	string inname = TestFilePath + TestFileName;
 	ifstream infile( inname, ios::in );
-	if(infile.bad()){
+	if ( infile.bad() ){
 	  cerr << "Cannot read from " << inname << endl;
 	  return 0;
 	}
@@ -327,8 +334,9 @@ struct more_second {
       Ktree->Learn( K_option_name );
       //      UKtree->ShowSettings( default_cout );
       Ktree->WriteInstanceBase( KnownTreeName );
-      if ( !kwf.empty() )
+      if ( !kwf.empty() ){
 	Ktree->SaveWeights( kwf );
+      }
       delete Ktree;
       if ( !KeepIntermediateFiles ){
 	remove(K_option_name.c_str());
@@ -344,13 +352,16 @@ struct more_second {
       COUT << "  Create unknown words case base,"
 	   << " Timbl options: '" << unknownstr + commonstr << "'" << endl;
       TimblAPI *UKtree = new TimblAPI( unknownstr + commonstr );
-      if ( !UKtree->Valid() )
-	exit(EXIT_FAILURE);
+      if ( !UKtree->Valid() ){
+	cerr << "unable to create Timbl(" << unknownstr + commonstr
+	     << ") for Unknown words." << endl;
+	return -1; // signal a failure
+      }
       COUT << "    Algorithm = " << to_string(UKtree->Algo()) << endl;
       if ( !piped_input ){
 	string inname = TestFilePath + TestFileName;
 	ifstream infile( inname, ios::in );
-	if(infile.bad()){
+	if( infile.bad() ){
 	  cerr << "Cannot read from " << inname << endl;
 	  return 0;
 	}
@@ -366,8 +377,9 @@ struct more_second {
       UKtree->Learn( U_option_name );
       //      UKtree->ShowSettings( COUT );
       UKtree->WriteInstanceBase( UnknownTreeName );
-      if ( !uwf.empty() )
+      if ( !uwf.empty() ){
 	UKtree->SaveWeights( uwf );
+      }
       delete UKtree;
       if ( !KeepIntermediateFiles ){
 	remove(U_option_name.c_str());
@@ -377,7 +389,7 @@ struct more_second {
     return nwords;
   }
 
-  void TaggerClass::CreateSettingsFile(){
+  bool TaggerClass::CreateSettingsFile(){
     if ( SettingsFileName.empty() ) {
       SettingsFileName = TestFileName + ".settings";
     }
@@ -386,11 +398,12 @@ struct more_second {
 	   !out_file.good() ) ){
       cerr << "couldn't create Settings-File `"
 	   << SettingsFileName << "'" << endl;
-      exit(EXIT_FAILURE);
+      return false;
     }
     else {
-      if ( input_kind == ENRICHED )
+      if ( input_kind == ENRICHED ){
 	out_file << "ENRICHED" << endl;
+      }
       out_file << "e " << EosMark << endl;
       out_file << "l " << MTLexFileBaseName << endl;
       out_file << "k " << KnownTreeBaseName << endl;
@@ -403,6 +416,7 @@ struct more_second {
       COUT << endl << "  Created settings file '"
 			 << SettingsFileName << "'" << endl;
     }
+    return true;
   }
 
   //**** stuff to process commandline options *****************************
@@ -412,11 +426,6 @@ struct more_second {
 
   bool TaggerClass::parse_create_args( TiCC::CL_Options& opts ){
     string value;
-    if ( opts.is_present( 'V' ) ||
-	 opts.is_present( "version" ) ){
-      // we already identified ourself. just bail out.
-      return false;
-    }
     if ( opts.extract( '%', value ) ){
       FilterThreshold = stringTo<int>( value );
     }
@@ -473,10 +482,12 @@ struct more_second {
       SettingsFileName = value;
       // extract the absolute path to the settingsfile
       string::size_type lastSlash = SettingsFileName.rfind('/');
-      if ( lastSlash != string::npos )
+      if ( lastSlash != string::npos ){
 	SettingsFilePath = SettingsFileName.substr( 0, lastSlash+1 );
-      else
+      }
+      else {
 	SettingsFilePath = "";
+      }
     }
     if ( opts.extract( 't', value ) ){
       TagListName = value;
@@ -490,8 +501,9 @@ struct more_second {
 	TestFilePath = TestFileName.substr( 0, lastSlash+1 );
 	TestFileName = TestFileName.substr( lastSlash+1 );
       }
-      else
+      else {
 	TestFilePath = "";
+      }
       piped_input = false;
       input_kind = ENRICHED; // an enriched tagged test file specified
     }
@@ -503,8 +515,9 @@ struct more_second {
 	TestFilePath = TestFileName.substr( 0, lastSlash+1 );
 	TestFileName = TestFileName.substr( lastSlash+1 );
       }
-      else
+      else {
 	TestFilePath = "";
+      }
       piped_input = false;
       input_kind = TAGGED; // there is a tagged test file specified
     }
@@ -551,7 +564,7 @@ struct more_second {
     return true;
   }
 
-  void gen_usage( const string& progname ){
+  void TaggerClass::gen_usage( const string& progname ){
     cerr << "Usage is : " << progname << " option option ...\n"
 	 << "\t-s settingsfile\n"
 	 << "\t-% <percentage> Filter Threshold for ambitag construction (default 5%)\n"
@@ -584,24 +597,20 @@ struct more_second {
     if ( opts.is_present( 'h' ) ||
 	 opts.is_present( "help" ) ){
       gen_usage( "mbtg" );
-      return -1;
+      return 0;
     }
     //
     // present yourself to the user
     //
-    cerr << "mbtg " << VERSION << " (c) CLST, ILK and CLiPS 1998 - 2018." << endl
-	 << "Memory Based Tagger Generator" << endl
-	 << "CLST  - Centre for Language and Speech Technology,"
-	 << "Radboud University" << endl
-	 << "ILK   - Induction of Linguistic Knowledge Research Group,"
-	 << "Tilburg University" << endl
-	 << "CLiPS - Computational Linguistics Group, University of Antwerp"
-	 << endl
-	 << "Based on " << Timbl::VersionName()
-	 << endl << endl;
+    if ( opts.is_present( 'V' ) ||
+	 opts.is_present( "version" ) ){
+      TaggerClass::manifest( "mbtg" );
+      return 0;
+    }
     TaggerClass tagger;
-    if ( !tagger.parse_create_args( opts ) )
+    if ( !tagger.parse_create_args( opts ) ){
       return -1;
+    }
     tagger.set_default_filenames();
     tagger.InitLearning();
     // process the test material
@@ -619,9 +628,15 @@ struct more_second {
 	uwords = tagger.CreateUnknown();
       }
     }
+    if ( kwords < 0 || uwords < 0 ){
+      cerr << "Generationg a tagger failed" << endl;
+      return -1;
+    }
     COUT << "      ready: " << kwords << " words processed."
 	 << endl;
-    tagger.CreateSettingsFile();
+    if ( !tagger.CreateSettingsFile() ){
+      return -1;
+    }
     return kwords + uwords;
   }
 
