@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 1998 - 2018
+  Copyright (c) 1998 - 2020
   CLST  - Radboud University
   ILK   - Tilburg University
   CLiPS - University of Antwerp
@@ -35,5 +35,10 @@
 using namespace std;
 
 int main(int argc, char *argv[]) {
-  MbtAPI::RunTagger( argc, argv );
+  if ( MbtAPI::RunTagger( argc, argv ) ){
+    return EXIT_SUCCESS;
+  }
+  else {
+    return EXIT_FAILURE;
+  }
 }
