@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 1998 - 2018
+  Copyright (c) 1998 - 2020
   CLST  - Radboud University
   ILK   - Tilburg University
   CLiPS - University of Antwerp
@@ -56,6 +56,15 @@ MbtAPI::MbtAPI( const std::string& optstring ){
     cerr << e.what() << endl;
     return;
   }
+  string progname = opts.prog_name();
+  if ( opts.extract('h') || opts.extract("help") ){
+    TaggerClass::run_usage( progname );
+    return;
+  }
+  if ( opts.extract('V') || opts.extract("version") ){
+    TaggerClass::manifest( progname );
+    return;
+  }
   tagger = TaggerClass::StartTagger( opts );
 }
 
@@ -69,6 +78,15 @@ MbtAPI::MbtAPI( const std::string& optstring, LogStream& ls ){
     cerr << e.what() << endl;
     return;
   }
+  string progname = opts.prog_name();
+  if ( opts.extract('h') || opts.extract("help") ){
+    TaggerClass::run_usage( progname );
+    return;
+  }
+  if ( opts.extract('V') || opts.extract("version") ){
+    TaggerClass::manifest( progname );
+    return;
+  }
   tagger = TaggerClass::StartTagger( opts, &ls );
 }
 
@@ -81,32 +99,36 @@ bool MbtAPI::isInit() const{
 }
 
 string MbtAPI::Tag( const std::string& inp ){
-  if ( tagger )
+  if ( tagger ){
     return tagger->Tag( inp );
+  }
   else {
     throw std::runtime_error( "No tagger initialized yet...." );
   }
 }
 
 vector<TagResult> MbtAPI::TagLine( const string& inp ){
-  if ( tagger )
+  if ( tagger ){
     return tagger->tagLine( inp );
+  }
   else {
     throw std::runtime_error( "No tagger initialized yet...." );
   }
 }
 
 string MbtAPI::getResult( const vector<TagResult>& v ) const {
-  if ( tagger )
+  if ( tagger ){
     return tagger->TRtoString( v );
+  }
   else {
     throw std::runtime_error( "No tagger initialized yet...." );
   }
 }
 
 string MbtAPI::set_eos_mark( const std::string& eos ){
-  if ( tagger )
+  if ( tagger ){
     return tagger->set_eos_mark( eos );
+  }
   else {
     throw std::runtime_error( "No tagger initialized yet...." );
   }
@@ -123,10 +145,14 @@ bool MbtAPI::GenerateTagger(int argc, char *argv[]) {
   if ( nw < 0 ){
     return false;
   }
+  else if ( nw == 0 ){
+    return true;
+  }
   time(&timeafter);
   timediff = timeafter - timebefore;
-  if ( timediff == 0 )
+  if ( timediff == 0 ){
     timediff = 1;
+  }
   cout << endl << "Ready:" << endl
        << "  Time used: " << timediff << endl
        << "  Words/sec: " << nw/(timediff) << endl;
@@ -144,10 +170,14 @@ bool MbtAPI::GenerateTagger( const std::string& arg ) {
   if ( nw < 0 ){
     return false;
   }
+  else if ( nw == 0 ){
+    return true;
+  }
   time(&timeafter);
   timediff = timeafter - timebefore;
-  if ( timediff == 0 )
+  if ( timediff == 0 ){
     timediff = 1;
+  }
   cout << endl << "Ready:" << endl
        << "  Time used: " << timediff << endl
        << "  Words/sec: " << nw/(timediff) << endl;
@@ -167,6 +197,15 @@ bool MbtAPI::RunTagger( int argc, char **argv ){
     cerr << e.what() << endl;
     return false;
   }
+  string progname = opts.prog_name();
+  if ( opts.extract('h') || opts.extract("help") ){
+    TaggerClass::run_usage( progname );
+    return true;
+  }
+  if ( opts.extract('V') || opts.extract("version") ){
+    TaggerClass::manifest( progname );
+    return true;
+  }
   TaggerClass *tagger = TaggerClass::StartTagger( opts );
   if ( !tagger ){
     return false;
@@ -174,8 +213,9 @@ bool MbtAPI::RunTagger( int argc, char **argv ){
   int nw = tagger->Run();
   time(&timeafter);
   timediff = timeafter - timebefore;
-  if ( timediff == 0 )
+  if ( timediff == 0 ){
     timediff = 1;
+  }
   cerr << "  Time used: " << timediff << endl;
   cerr << "  Words/sec: " << nw/(timediff) << endl;
   delete tagger;
