@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 1998 - 2018
+  Copyright (c) 1998 - 2020
   CLST  - Radboud University
   ILK   - Tilburg University
   CLiPS - University of Antwerp
@@ -30,6 +30,10 @@
 #include "mbt/MbtAPI.h"
 
 int main(int argc, char *argv[]) {
-  MbtAPI::GenerateTagger( argc, argv );
-  exit(EXIT_SUCCESS);
+  if ( MbtAPI::GenerateTagger( argc, argv ) ){
+    return EXIT_SUCCESS;
+  }
+  else {
+    return EXIT_FAILURE;
+  }
 }
