@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 1998 - 2018
+  Copyright (c) 1998 - 2020
   CLST  - Radboud University
   ILK   - Tilburg University
   CLiPS - University of Antwerp
@@ -41,6 +41,8 @@
 #include "config.h"
 #include "timbl/TimblAPI.h"
 #include "ticcutils/Timer.h"
+#include "ticcutils/PrettyPrint.h"
+#include "ticcutils/json.hpp"
 #include "mbt/Pattern.h"
 #include "mbt/Sentence.h"
 #include "mbt/Logging.h"
@@ -51,11 +53,13 @@
 #endif
 
 using namespace TiCC;
+using namespace nlohmann;
 
 namespace Tagger {
   using namespace std;
   using namespace Hash;
   using namespace Timbl;
+  using TiCC::operator<<;
 
   const string UNKSTR   = "UNKNOWN";
 
@@ -124,8 +128,9 @@ namespace Tagger {
 
   void BeamData::ClearBest(){
     DBG << "clearing n_best_array..." << endl;
-    for ( int i=0; i < size; ++i )
+    for ( int i=0; i < size; ++i ){
       n_best_array[i]->clean();
+    }
   }
 
   void BeamData::Shift(	int no_words, int i_word ){
@@ -143,16 +148,19 @@ namespace Tagger {
 		<< " into paths[" << jb << "," << q1 << "]" << endl;
 	    temppaths[jb][q1] = n_best_array[jb]->tag;
 	  }
-	  else
+	  else {
 	    temppaths[jb][q1] = EMPTY_PATH;
+	  }
 	}
-	else
+	else {
 	  temppaths[jb][q1] = EMPTY_PATH;
+	}
       }
     }
     for ( int jb = 0; jb < size; ++jb ){
-      for ( int q1=0; q1 < no_words; ++q1 )
+      for ( int q1=0; q1 < no_words; ++q1 ){
 	paths[jb][q1] = temppaths[jb][q1];
+      }
     }
   }
 
@@ -204,8 +212,9 @@ namespace Tagger {
 
   name_prob_pair *add_descending( name_prob_pair *n, name_prob_pair *lst ){
     name_prob_pair *result;
-    if ( lst == 0 )
+    if ( lst == 0 ){
       result = n;
+    }
     else if ( n->prob - lst->prob >= 0 ){
       result = n;
       n->next = lst;
@@ -231,21 +240,23 @@ namespace Tagger {
     double sum_freq = 0.0;
     for ( const auto& it : *Dist ){
       string name = it.second->Value()->Name();
-      //      string name = (*it).second->Value()->Name();
       double freq = it.second->Weight();
       sum_freq += freq;
       tmp = new name_prob_pair( name, freq );
-      if ( name == PrefClass->Name() )
+      if ( name == PrefClass->Name() ){
+	assert( Pref == 0 );
 	Pref = tmp;
-      else
+      }
+      else {
 	result = add_descending( tmp, result );
+      }
     }
     if ( Pref ){
       Pref->next = result;
       result = Pref;
     }
     //
-    // Now we must Normalize te get real Probalilities
+    // Now we must Normalize te get real Probabilities
     tmp = result;
     while ( tmp ){
       tmp->prob = tmp->prob / sum_freq;
@@ -304,17 +315,19 @@ namespace Tagger {
 	  double thisWProb = d_pnt->prob;
 	  double thisPProb = thisWProb * path_prob[beam_cnt];
 	  int dtag = TheLex.Hash( d_pnt->name );
-	  for( int ane = size-1; ane >=0; --ane ){
+	  for ( int ane = size-1; ane >=0; --ane ){
 	    if ( thisPProb <= n_best_array[ane]->prob )
 	      break;
 	    if ( ane == 0 ||
 		 thisPProb <= n_best_array[ane-1]->prob ){
- 	      if ( ane == 0 )
+ 	      if ( ane == 0 ){
  		DBG << "Insert, n=0" << endl;
- 	      else
+	      }
+ 	      else {
  		DBG << "Insert, n=" << ane << " Prob = " << thisPProb
 		    << " after prob = " << n_best_array[ane-1]->prob
 		    << endl;
+	      }
 	      // shift
 	      n_best_tuple *keep = n_best_array[size-1];
 	      for ( int ash = size-1; ash > ane; --ash ){
@@ -362,7 +375,7 @@ namespace Tagger {
 
   void TaggerClass::ShowCats( ostream& os, const vector<int>& Pat, int slots ){
     os << "Pattern : ";
-    for( int slot=0; slot < slots; ++slot ){
+    for ( int slot=0; slot < slots; ++slot ){
       os << indexlex( Pat[slot], TheLex )<< " ";
     }
     os << endl;
@@ -373,12 +386,14 @@ namespace Tagger {
 				     MatchAction action,
 				     int word ){
     int slots;
-    if ( action == Unknown )
+    if ( action == Unknown ){
       slots = Utemplate.totalslots() - Utemplate.skipfocus;
-    else
+    }
+    else {
       slots = Ktemplate.totalslots() - Ktemplate.skipfocus;
+    }
     string line;
-    for( int f=0; f < slots; ++f ){
+    for ( int f=0; f < slots; ++f ){
       line += indexlex( pat[f], TheLex );
       line += " ";
     }
@@ -386,17 +401,19 @@ namespace Tagger {
     for ( const auto& er: enr ){
       line += er + " ";
     }
-    if ( input_kind != UNTAGGED )
+    if ( input_kind != UNTAGGED ){
       line += mySentence.gettag(word);
-    else
+    }
+    else {
       line += "??";
+    }
     if ( IsActive(DBG) ){
       ShowCats( LOG, pat, slots );
     }
     // dump if desired
     //
     if ( dumpflag ){
-      for( int slot=0; slot < slots; ++slot ){
+      for ( int slot=0; slot < slots; ++slot ){
 	cout << indexlex( pat[slot], TheLex );
       }
       cout << endl;
@@ -410,7 +427,7 @@ namespace Tagger {
     int no_words=0;
     ifstream lexfile( FileName, ios::in);
     while ( lexfile >> wordbuf >> valbuf ){
-      MT_lexicon->Store( wordbuf, valbuf );
+      MT_lexicon->insert(make_pair(wordbuf,valbuf));
       no_words++;
       lexfile >> ws;
     }
@@ -446,10 +463,12 @@ namespace Tagger {
     //
     read_listfile( TopNFileName, kwordlist );
 
-    if ( TimblOptStr.empty() )
+    if ( TimblOptStr.empty() ){
       Timbl_Options = "-FColumns ";
-    else
+    }
+    else {
       Timbl_Options = TimblOptStr;
+    }
 
     // we want Timbl to run silently ALWAYS
     // so overrule all -vS settings from old versions
@@ -466,20 +485,22 @@ namespace Tagger {
 	return false;
       }
     }
-    if( !knowntreeflag ){
+    if ( !knowntreeflag ){
       cerr << "<knowntreefile> not specified" << endl;
       return false;
     }
-    else if( !unknowntreeflag){
+    else if ( !unknowntreeflag ){
       cerr << "<unknowntreefile> not specified" << endl;
       return false;
     }
     KnownTree = new TimblAPI( knownstr + commonstr );
-    if ( !KnownTree->Valid() )
+    if ( !KnownTree->Valid() ){
       return false;
+    }
     unKnownTree = new TimblAPI( unknownstr + commonstr );
-    if ( !unKnownTree->Valid() )
+    if ( !unKnownTree->Valid() ){
       return false;
+    }
     // read a previously stored InstanceBase for known words
     //
     LOG << "  Reading case-base for known words from: " << KnownTreeName
@@ -497,15 +518,16 @@ namespace Tagger {
 	  cerr << "Couldn't read known weights from " << kwf << endl;
 	  return false;
 	}
-	else
+	else {
 	  cerr << "\n  Read known weights from " << kwf << endl;
+	}
       }
       LOG << "  case-base for known words read." << endl;
       // read  a previously stored InstanceBase for unknown words
       //
       LOG << "  Reading case-base for unknown words from: "
 	  << UnknownTreeName << "... " << endl;
-      if( !unKnownTree->GetInstanceBase( UnknownTreeName) ){
+      if ( !unKnownTree->GetInstanceBase( UnknownTreeName) ){
 	LOG << "Could not read the unknown tree from "
 	     << UnknownTreeName << endl;
 	return false;
@@ -516,8 +538,9 @@ namespace Tagger {
 	    cerr << "Couldn't read unknown weights from " << uwf << endl;
 	    return false;
 	  }
-	  else
+	  else {
 	    LOG << "\n  Read unknown weights from " << uwf << endl;
+	  }
 	}
 	LOG << "  case-base for unknown word read" << endl;
       }
@@ -550,7 +573,7 @@ namespace Tagger {
       if ( !piped_input ){
 	string inname = TestFilePath + TestFileName;
 	infile.open(inname, ios::in);
-	if( infile.bad( )){
+	if ( infile.bad( ) ){
 	  cerr << "Cannot read from " << inname << endl;
 	  result = 0;
 	}
@@ -566,8 +589,9 @@ namespace Tagger {
 	  cerr << "Enriched Inputformat not supported for stdin, sorry"
 	       << endl;
 	}
-	else
+	else {
 	  result = ProcessFile( cin, *os );
+	}
       }
       if ( out_to_file ){
 	delete os;
@@ -586,8 +610,9 @@ namespace Tagger {
 					    double& distance ){
     const TargetValue *answer = 0;
 #if defined(HAVE_PTHREAD)
-    if ( cloned )
+    if ( cloned ){
       pthread_mutex_lock( &timbl_lock );
+    }
 #endif
     timer1.start();
     if ( Action == Known ){
@@ -602,8 +627,9 @@ namespace Tagger {
     }
     timer1.stop();
 #if defined(HAVE_PTHREAD)
-    if ( cloned )
+    if ( cloned ){
       pthread_mutex_unlock( &timbl_lock );
+    }
 #endif
     if ( !answer ){
       throw runtime_error( "Tagger: A classifying problem prevented continuing. Sorry!" );
@@ -622,13 +648,16 @@ namespace Tagger {
     distance_array.resize( mySentence.size() );
     distribution_array.resize( mySentence.size() );
     confidence_array.resize( mySentence.size() );
-    if ( distance_flag )
+    if ( distance_flag ){
       distance_array[0] = distance;
+    }
     if ( distribution ){
-      if ( distrib_flag )
+      if ( distrib_flag ){
 	distribution_array[0] = distribution->DistToString();
-      if ( confidence_flag )
+      }
+      if ( confidence_flag ){
 	confidence_array[0] = distribution->Confidence( answer );
+      }
       if ( IsActive( DBG ) ){
 	LOG << "BeamData::InitPaths( " << mySentence << endl;
 	LOG << " , " << answer << " , " << distribution << " )" << endl;
@@ -662,13 +691,16 @@ namespace Tagger {
       const TargetValue *answer = Classify( Action, teststring,
 					    &distribution, distance );
       if ( beam_cnt == 0 ){
-	if ( distance_flag )
+	if ( distance_flag ){
 	  distance_array[i_word] = distance;
+	}
 	if ( distribution ){
-	  if ( distrib_flag )
+	  if ( distrib_flag ){
 	    distribution_array[i_word] = distribution->DistToString();
-	  if ( confidence_flag )
+	  }
+	  if ( confidence_flag ){
 	    confidence_array[i_word] = distribution->Confidence( answer );
+	  }
 	}
       }
       if ( IsActive( DBG ) ){
@@ -676,8 +708,9 @@ namespace Tagger {
 	LOG << " , " << answer << " , " << distribution << " )" << endl;
       }
       Beam->NextPath( TheLex, answer, distribution, beam_cnt );
-      if ( IsActive( DBG ) )
+      if ( IsActive( DBG ) ){
 	Beam->PrintBest( LOG, TheLex );
+      }
       return true;
     }
     else {
@@ -699,6 +732,81 @@ namespace Tagger {
     return tagSentence( mySentence );
   }
 
+  json TaggerClass::tag_line_to_JSON( const string& line ){
+    sentence mySentence( Ktemplate, Utemplate );
+    stringstream ss(line);
+    size_t dummy = 0;
+    mySentence.read( ss, input_kind, EosMark, Separators, dummy );
+    vector<TagResult> tag_results = tagSentence( mySentence );
+    json result = json::array();
+    for ( const auto& tr : tag_results ){
+      // lookup the assigned category
+      json one_entry;
+      one_entry["word"] = tr.word();
+      one_entry["known"] = tr.is_known();
+      if ( enriched() ){
+	one_entry["enrichment"] = tr.enrichment();
+      }
+      one_entry["tag"] = tr.assigned_tag();
+      if ( confidence_is_set() ){
+	one_entry["confidence"] = tr.confidence();
+      }
+      if ( distrib_is_set() ){
+	one_entry["distribution"] = tr.distribution();
+      }
+      if ( distance_is_set() ){
+	one_entry["distance"] = tr.distance();
+      }
+      result.push_back( one_entry );
+    }
+    return result;
+  }
+
+  string extract_text( const json& my_json ){
+    string result;
+    if ( my_json.is_array() ){
+      for ( const auto& it : my_json ){
+	string tmp = it["word"];
+	result += tmp + " ";
+	if ( it.find("enrichment") != it.end() ){
+	  tmp = it["enrichment"];
+	  result += tmp + " ";
+	  if ( it.find("tag") != it.end() ){
+	    tmp = it["tag"];
+	    result += tmp;
+	  }
+	  else {
+	    result += "??";
+	  }
+	  result += "\n";
+	}
+      }
+    }
+    else {
+      string tmp = my_json["word"];
+      result += tmp +  " ";
+      if ( my_json.find("enrichment") != my_json.end() ){
+	tmp = my_json["enrichment"];
+	result += tmp + " ";
+	if ( my_json.find("tag") != my_json.end() ){
+	  tmp = my_json["tag"];
+	  result += tmp;
+	}
+	else {
+	  result += "??";
+	}
+	result += "\n";
+      }
+    }
+    return result;
+  }
+
+  json TaggerClass::tag_JSON_to_JSON( const json& in ){
+    json result;
+    string line = extract_text( in );
+    return tag_line_to_JSON( line );
+  }
+
   vector<TagResult> TaggerClass::tagSentence( sentence& mySentence ){
     vector<TagResult> result;
     if ( mySentence.size() != 0 ){
@@ -721,8 +829,9 @@ namespace Tagger {
 	    DBG << endl << "Next: " << mySentence.getword( iword ) << endl;
 	    Beam->ClearBest();
 	    for ( int beam_count=0; beam_count < Beam_Size; ++beam_count ){
-	      if ( !NextBest( mySentence, TestPat, iword, beam_count ) )
+	      if ( !NextBest( mySentence, TestPat, iword, beam_count ) ){
 		break;
+	      }
 	    }
 	    Beam->Shift( mySentence.size(), iword );
 	    if ( IsActive( DBG ) ){
@@ -738,19 +847,23 @@ namespace Tagger {
 	// get the original word
 	res._word= mySentence.getword(Wcnt);
 	// get the original tag
-	res._inputTag = mySentence.gettag(Wcnt);
+	res._input_tag = mySentence.gettag(Wcnt);
 	// lookup the assigned tag
 	res._tag = indexlex( Beam->paths[0][Wcnt], TheLex );
 	// is it known/unknown
 	res._known = mySentence.known(Wcnt);
-	if ( input_kind == ENRICHED )
+	if ( input_kind == ENRICHED ){
 	  res._enrichment = mySentence.getenr(Wcnt);
-	if ( confidence_flag )
+	}
+	if ( confidence_flag ){
 	  res._confidence = confidence_array[Wcnt];
-	if ( distrib_flag )
+	}
+	if ( distrib_flag ){
 	  res._distribution = distribution_array[Wcnt];
-	if ( distance_flag )
+	}
+	if ( distance_flag ){
 	  res._distance = distance_array[Wcnt];
+	}
 	result.push_back( res );
       }
     } // end of output loop through one sentence
@@ -758,10 +871,12 @@ namespace Tagger {
   }
 
   string decode( const string& eom ){
-    if ( eom  == "EL" )
+    if ( eom  == "EL" ){
       return "";
-    else
+    }
+    else {
       return eom;
+    }
   }
 
   string TaggerClass::TRtoString( const vector<TagResult>& trs ) const {
@@ -769,42 +884,52 @@ namespace Tagger {
     for ( const auto& tr : trs ){
       // lookup the assigned category
       result += tr.word();
-      if ( tr.isKnown() ){
-	if ( input_kind == UNTAGGED )
+      if ( tr.is_known() ){
+	if ( input_kind == UNTAGGED ){
 	  result += "/";
-	else
+	}
+	else {
 	  result += "\t/\t";
+	}
       }
       else {
-	if ( input_kind == UNTAGGED )
+	if ( input_kind == UNTAGGED ){
 	  result += "//";
-	else
+	}
+	else {
 	  result += "\t//\t";
+	}
       }
       // output the correct tag if possible
       //
-      if ( input_kind == ENRICHED )
+      if ( input_kind == ENRICHED ){
 	result = result + tr.enrichment() + "\t";
+      }
       if ( input_kind == TAGGED ||
 	   input_kind == ENRICHED ){
-	result += tr.inputTag() + "\t" + tr.assignedTag();
-	if ( confidence_flag )
+	result += tr.input_tag() + "\t" + tr.assigned_tag();
+	if ( confidence_flag ){
 	  result += " [" + toString( tr.confidence() ) + "]";
-	if ( distrib_flag )
+	}
+	if ( distrib_flag ){
 	  result += " " + tr.distribution();
-	if ( distance_flag )
+	}
+	if ( distance_flag ){
 	  result += " " + toString( tr.distance() );
+	}
 	result += "\n";
       }
       else {
-	result += tr.assignedTag();
-	if ( confidence_flag )
+	result += tr.assigned_tag();
+	if ( confidence_flag ){
 	  result += "/" + toString( tr.confidence() );
+	}
 	result += " ";
       }
     } // end of output loop through one sentence
-    if ( input_kind != ENRICHED )
+    if ( input_kind != ENRICHED ){
       result = result + decode( EosMark );
+    }
     return result;
   }
 
@@ -819,22 +944,23 @@ namespace Tagger {
       if ( mySentence.known(Wcnt) ){
 	no_known++;
 	if ( input_kind != UNTAGGED ){
-	  if ( mySentence.gettag(Wcnt) == tagstring )
-	    no_correct_known++;
+	  if ( mySentence.gettag(Wcnt) == tagstring ){
+	    ++no_correct_known;
+	  }
 	}
       }
       else {
 	no_unknown++;
 	if ( input_kind != UNTAGGED ){
-	  if ( mySentence.gettag(Wcnt) == tagstring )
-	    no_correct_unknown++;
+	  if ( mySentence.gettag(Wcnt) == tagstring ){
+	    ++no_correct_unknown;
+	  }
 	}
       }
     } // end of output loop through one sentence
   }
 
   int TaggerClass::ProcessFile( istream& infile, ostream& outfile ){
-    bool go_on = true;
     int no_words=0;
     int no_correct_known=0;
     int no_correct_unknown=0;
@@ -846,8 +972,7 @@ namespace Tagger {
     int HartBeat = 0;
     size_t line_cnt = 0;
     sentence mySentence( Ktemplate, Utemplate );
-    while ( go_on &&
-	    mySentence.read(infile, input_kind, EosMark, Separators, line_cnt ) ){
+    while ( mySentence.read(infile, input_kind, EosMark, Separators, line_cnt ) ){
       if ( mySentence.size() == 0 )
 	continue;
       if ( ++HartBeat % 100 == 0 ) {
@@ -894,10 +1019,11 @@ namespace Tagger {
       else {
 	cerr << "  Known   words: " << no_known << endl;
 	cerr << "  Unknown words: " << no_unknown;
-	if ( no_unknown > 0 )
+	if ( no_unknown > 0 ){
 	  cerr << " ("
 	       << ((float)(no_unknown)/(float)(no_unknown+no_known))*100
 	       << " %)";
+	}
 	cerr << endl;
 	cerr << "  Total        : " << no_known+no_unknown << endl;
       }
@@ -908,7 +1034,7 @@ namespace Tagger {
 
   bool TaggerClass::readsettings( string& fname ){
     ifstream setfile( fname, ios::in);
-    if( !setfile ){
+    if ( !setfile ){
       return false;
     }
     char SetBuffer[512];
@@ -916,8 +1042,9 @@ namespace Tagger {
     while(setfile.getline(SetBuffer,511,'\n')){
       switch (SetBuffer[0]) {
       case 'B':
-	if ( sscanf(SetBuffer,"B %40d", &Beam_Size ) != 1 )
+	if ( sscanf(SetBuffer,"B %40d", &Beam_Size ) != 1 ){
 	  Beam_Size = 1;
+	}
 	break;
       case 'd':
 	dumpflag=true;
@@ -971,12 +1098,6 @@ namespace Tagger {
 						SettingsFilePath );
 	reverseflag = true;
 	break;
-      case 'S':
-	cerr << "Server mode NOT longer supported in this version!\n"
-	     << "use mbtserver instead\n"
-	     << "sorry..." << endl;
-	exit(EXIT_FAILURE);
-	break;
       case 't':
 	sscanf(SetBuffer,"t %300s", value );
 	TestFileName = value;
@@ -992,8 +1113,9 @@ namespace Tagger {
 	  piped_input = false;
 	  input_kind = ENRICHED; // an enriched tagged test file specified
 	}
-	else if ( !strncmp( SetBuffer, "ENRICHED", 8 ) )
+	else if ( !strncmp( SetBuffer, "ENRICHED", 8 ) ){
 	  input_kind = ENRICHED; // an enriched tagged test file specified
+	}
 	else {
 	  cerr << "Unknown option in settingsfile, ("
 	       << SetBuffer << "), ignored." <<endl;
@@ -1033,37 +1155,46 @@ namespace Tagger {
       SettingsFileName = value;
       // extract the absolute path to the settingsfile
       string::size_type lastSlash = SettingsFileName.rfind('/');
-      if ( lastSlash != string::npos )
+      if ( lastSlash != string::npos ){
 	SettingsFilePath = SettingsFileName.substr( 0, lastSlash+1 );
-      else
+      }
+      else {
 	SettingsFilePath = "";
-      if( !readsettings( SettingsFileName ) ){
+      }
+      if ( !readsettings( SettingsFileName ) ){
 	cerr << "Cannot read settingsfile " << SettingsFileName << endl;
 	return false;
       }
     };
     if ( Opts.extract( 'B', value ) ){
       int dum_beam = stringTo<int>(value);
-      if (dum_beam>1)
+      if ( dum_beam > 1 ){
 	Beam_Size = dum_beam;
-      else
+      }
+      else {
 	Beam_Size = 1;
+      }
     };
     if ( Opts.extract( 'd', value ) ){
       dumpflag=true;
       cerr << "  Dumpflag ON" << endl;
     }
     if ( Opts.extract( 'D', value ) ){
-      if ( value == "LogSilent" )
+      if ( value == "LogSilent" ) {
 	cur_log->setlevel( LogSilent );
-      else if ( value == "LogNormal" )
+      }
+      else if ( value == "LogNormal" ){
 	cur_log->setlevel( LogNormal );
-      else if ( value == "LogDebug" )
+      }
+      else if ( value == "LogDebug" ){
 	cur_log->setlevel( LogDebug );
-      else if ( value == "LogHeavy" )
+      }
+      else if ( value == "LogHeavy" ){
 	cur_log->setlevel( LogHeavy );
-      else if ( value == "LogExtreme" )
+      }
+      else if ( value == "LogExtreme" ){
 	cur_log->setlevel( LogExtreme );
+      }
       else {
 	cerr << "Unknown Debug mode! (-D " << value << ")" << endl;
       }
@@ -1154,10 +1285,10 @@ namespace Tagger {
     return true;
   }
 
-  void TaggerClass::manifest(){
+  void TaggerClass::manifest( const string& prog ){
     // present yourself to the user
     //
-    cerr << "mbt " << VERSION << " (c) CLST, ILK and CLiPS 1998 - 2018." << endl
+    cerr << prog << " " << VERSION << " (c) CLST, ILK and CLiPS 1998 - 2020." << endl
 	 << "Memory Based Tagger " << endl
 	 << "CLST  - Centre for Language and Speech Technology,"
 	 << "Radboud University" << endl
@@ -1172,7 +1303,7 @@ namespace Tagger {
   const std::string mbt_short_opts = "hv:VB:dD:e:k:l:L:o:O:r:s:t:E:T:u:";
   const std::string mbt_long_opts  = "help,version,settings:,tabbed";
 
-  void run_usage( const string& progname ){
+  void TaggerClass::run_usage( const string& progname ){
     cerr << "Usage is : " << progname << " option option ... \n"
 	 << "\t-s settingsfile  ...or:\n\n"
 	 << "\t-l <lexiconfile>\n"
@@ -1202,24 +1333,18 @@ namespace Tagger {
 
   TaggerClass *TaggerClass::StartTagger( TiCC::CL_Options& opts,
 					 LogStream* os ){
-    string progname = opts.prog_name();
-    if ( opts.extract('h') || opts.extract("help") ){
-      run_usage( progname );
-      return 0;
-    }
-    if ( opts.extract('V') || opts.extract("version") ){
-      manifest();
-      return 0;
-    }
     TaggerClass *tagger = new TaggerClass;
     if ( !tagger->parse_run_args( opts ) ){
       delete tagger;
       return 0;
     }
-    if ( os )
+    if ( os ){
       tagger->setLog( *os );
-    else // only manifest() when running 'standalone'
-      manifest();
+    }
+    else {
+      // only manifest() when running 'standalone'
+      manifest( "mbt" );
+    }
     tagger->set_default_filenames();
     tagger->InitTagging();
     return tagger;
