@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 1998 - 2018
+  Copyright (c) 1998 - 2020
   CLST  - Radboud University
   ILK   - Tilburg University
   CLiPS - University of Antwerp
@@ -43,8 +43,10 @@ int main(){
   string command = "-T " + path + "/example/eindh.data -s ./simple.setting";
   MbtAPI::GenerateTagger( command );
   MbtAPI demo( "-s ./simple.setting" );
+  cerr << "version: " << Tagger::Version() << endl;
+  cerr << "name: " << Tagger::VersionName() << endl;
   cerr << demo.Tag( "dit is een test" ) << endl;
   vector<TagResult> v = demo.TagLine( "Test regel 2 ." );
-  assert( v[0].assignedTag() == "N" );
+  assert( v[0].assigned_tag() == "N" );
   assert( v[2].confidence() == -1 );
 }
